.. Accellera IP-XACT DE (Design Environment) documentation

.. toctree::
   :hidden:
   :caption: Introduction

   intro/release_notes
   intro/references

.. intro/introduction
.. intro/status
.. intro/setup
.. intro/faq

.. toctree::
   :hidden:
   :caption: API Reference
   :maxdepth: 2

   api/amal.eda
   api/amal.eda.ipxact_de
   api/amal.eda.ipxact_de.cli
   api/amal.eda.ipxact_de.gui
   api/amal.eda.ipxact_de.gui.ui
   api/amal.eda.ipxact_de.tgi
   api/amal.eda.ipxact_de.tgi.ipxact
   api/amal.eda.ipxact_de.tgi.ipxact.v1685_2022
   api/amal.eda.ipxact_de.web
   api/amal.utilities
   api/org.accellera
   api/org.accellera.spirit
   api/org.accellera.spirit.v1_0
   api/org.accellera.spirit.v1_1
   api/org.accellera.spirit.v1_2
   api/org.accellera.spirit.v1_4
   api/org.accellera.spirit.v1_4.tgi
   api/org.accellera.spirit.v1_5
   api/org.accellera.spirit.v1_5.tgi
   api/org.accellera.spirit.v1685_2009
   api/org.accellera.spirit.v1685_2009.tgi
   api/org.accellera.spirit.v1685_2009.ve
   api/org.accellera.spirit.v1685_2009.ve.ams
   api/org.accellera.spirit.v1685_2009.ve.core
   api/org.accellera.spirit.v1685_2009.ve.pdp
   api/org.accellera.spirit.v1685_2009.ve.power
   api/org.accellera.ipxact
   api/org.accellera.ipxact.v1685_2014
   api/org.accellera.ipxact.v1685_2022
   api/org.accellera.ipxact.v1685_2022.tgi
   api/org.accellera.ipxact.v1685_2022.ve

..   api/amal
..   api/amal.eda
..   api/org


Accellera IP-XACT DE (Design Environment) documentation
=======================================================

.. image:: _static/logo-256x256.png
    :width: 40%
    :align: center


``ipxact-de`` is a Python-based Design Environment and bindings for Accellera SPIRIT/IP-XACT.

.. .. mdinclude:: ../README.md
.. .. include:: ../README.md
..    :heading-offset: 1
